Configuration Options
=====================

Flaat instances are configured like :class:`FlaatConfig` below.


.. autoclass:: flaat.config.FlaatConfig
   :members:

.. autoclass:: flaat.config.AccessLevel
   :members:
